@@ -38,25 +38,30 @@ class InstrumentWrapper(param.Parameterized):
         ports = find_ports()
         self.devices = {}
         for module in self.modules:
-            mname = self.modules[module]["name"]
-            for hwid in self.modules[module]["hwid"]:
-                if hwid == "software":
-                    name = self.modules[module]["name"]
-                    self.devices[name] = {"name": name, "hwid": "software", "serial_number": "software",
-                                          "module": module, "port": "software"}
-                else:
-                    for port in ports:
-                        if debug == True:
-                            print(hwid)
-                            print(port.hwid.split(" ")[1].replace("VID:PID=", ""))
-                        if str(hwid) == port.hwid.split(" ")[1].replace("VID:PID=", ""):
-                            if port.serial_number in self.modules[module]["serial"] or self.modules[module][
-                                "serial"] is "any":
-                                name = f"{port.serial_number} - {port.name} - {mname} - {port.name}"
-                                self.devices[name] = {"name": port.name, "hwid": port.hwid,
-                                                      "serial_number": port.serial_number, "module": module,
-                                                      "port": port}
-        self.param["instrument_selected"].objects = self.devices.keys()
+            if self.modules[module]["function"] == "default":
+                mname = self.modules[module]["name"]
+                for hwid in self.modules[module]["hwid"]:
+                    if hwid == "software":
+                        name = self.modules[module]["name"]
+                        self.devices[name] = {"name": name, "hwid": "software", "serial_number": "software",
+                                              "module": module, "port": "software"}
+                    else:
+                        for port in ports:
+                            if debug == True:
+                                print(hwid)
+                                print(port.hwid.split(" ")[1].replace("VID:PID=", ""))
+                            if str(hwid) == port.hwid.split(" ")[1].replace("VID:PID=", ""):
+                                if port.serial_number in self.modules[module]["serial"] or self.modules[module]["serial"] == "any":
+                                    name = f"{port.serial_number} - {port.name} - {mname} - {port.name}"
+                                    self.devices[name] = {"name": port.name, "hwid": port.hwid,
+                                                          "serial_number": port.serial_number, "module": module,
+                                                          "port": port}
+                self.param["instrument_selected"].objects = self.devices.keys()
+            else:
+                for device in self.modules[module]["function"]():
+                    self.devices[device] = {"name": device, "hwid": device, "serial_number": device, "module": module,
+                                            "port": device}
+                self.param["instrument_selected"].objects = self.devices.keys()
 
     @param.depends("instrument_selected", watch=True)
     def load_device(self):
